==> downloads.php?download=SonikBB-0.0.24.zip: SonikBB-0.0.24/README.md <==
# SonikBB

![Screenshot 2025-02-21 111732](https://github.com/user-attachments/assets/e7be1900-3b5f-4841-a0c8-ed09cbd6d65c)

# My main idea is that every new programmer can understand and contribute to the forum or just play and learn new things for himself.

SonikBB is a lightweight and fast forum written in PHP. It is designed to be easy to use and configure, while providing all the necessary features for a modern forum.

## Features

*   **Easy to install**: Installation takes only a few minutes.
*   **Fast and efficient**: SonikBB is optimized for fast performance and low server load.
*   **Modular structure**: The forum is built on a modular principle, which allows easy adding and removing of functionalities.
*   **Theme support**: SonikBB supports various themes that can be customized to the user's taste.
*   **Admin panel**: Convenient admin panel for managing the forum.

## Installation

1.  Create a database named `sonikbb` or something else.
2.  Point your browser to http://websitename.com/install
3.  Follow the instructions
4.  Copy the installer config.php to the sonikbb root directory config.php
5.  Go to your new website and have fun
6.  chmod 777 uploads && uploads/versions && download_counts.txt
7.  remove install folder after install

( simple tutorial with pictures here https://sonikbb.eu/topic.php?topic_id=114&cat_id=46 )

## Upgrade

1. Delete all files and folders EXCEPT uploads and config.php
2. Do not upload Install folder
3. Upload ALL other files and folders

## Requirements

*   PHP 7.0 or later
*   MySQL 5.0 or later

## Development

SonikBB is under development and new features and improvements are constantly being added. If you want to contribute to the development of the forum, you can submit a pull request or create a new issue in the GitHub repository.

## License
MIT License

## Contacts

If you have any questions or suggestions, you can contact me through GitHub.

## Acknowledgements

Thank you to everyone who contributed to the development of SonikBB!

## Site of the project

https://sonikbb.eu/

![Screenshot 2025-02-21 111606](https://github.com/user-attachments/assets/df366d8d-a32c-4bcb-a6ad-95a0d4f34568)

![Screenshot 2025-02-21 111616](https://github.com/user-attachments/assets/de2724a1-00b2-4592-afd2-70d2916f02f0)

==> downloads.php?download=SonikBB-0.1.03.zip: SonikBB-0.1.03/README.md <==
# SonikBB

![Screenshot 2025-02-21 111732](https://github.com/user-attachments/assets/e7be1900-3b5f-4841-a0c8-ed09cbd6d65c)

# My main idea is that every new programmer can understand and contribute to the forum or just play and learn new things for himself.

SonikBB is a lightweight and fast forum written in PHP. It is designed to be easy to use and configure, while providing all the necessary features for a modern forum.

## Features

*   **Easy to install**: Installation takes only a few minutes.
*   **Fast and efficient**: SonikBB is optimized for fast performance and low server load.
*   **Modular structure**: The forum is built on a modular principle, which allows easy adding and removing of functionalities.
*   **Theme support**: SonikBB supports various themes that can be customized to the user's taste.
*   **Admin panel**: Convenient admin panel for managing the forum.

## Installation

1.  Create a database named `sonikbb` or something else.
2.  Point your browser to http://websitename.com/install
3.  Follow the instructions
4.  Copy the installer config.php to the sonikbb root directory /CORE/config.php
5.  (/VAR/WWW/SONIKBB/CORE/CONFIG.PHP
6.  Go to your new website and have fun
7.  chmod 777 uploads && uploads/versions && download_counts.txt
8.  remove install folder after install

( simple tutorial with pictures here https://sonikbb.eu/topic.php?topic_id=114&cat_id=46 )

## Upgrade

1. Delete all files and folders EXCEPT uploads and config.php
2. Do not upload Install folder
3. Upload ALL other files and folders

## Requirements

*   PHP 7.0 or later
*   MySQL 5.0 or later

## Development

SonikBB is under development and new features and improvements are constantly being added. If you want to contribute to the development of the forum, you can submit a pull request or create a new issue in the GitHub repository.

## License
MIT License

## Contacts

If you have any questions or suggestions, you can contact me through GitHub.

## Acknowledgements

Thank you to everyone who contributed to the development of SonikBB!

## Site of the project

https://sonikbb.eu/

![Screenshot 2025-02-21 111606](https://github.com/user-attachments/assets/df366d8d-a32c-4bcb-a6ad-95a0d4f34568)

![Screenshot 2025-02-21 111616](https://github.com/user-attachments/assets/de2724a1-00b2-4592-afd2-70d2916f02f0)
